==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/analysis/ReferenceDetector.h <==
// public class org.dellroad.jc.cgen.analysis.ReferenceDetector

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 596609dfe74eee9e org_dellroad_jc_cgen_analysis_ReferenceDetector
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_ReferenceDetector_H_
#define _JC_org_dellroad_jc_cgen_analysis_ReferenceDetector_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_NewExpr$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_refs	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$refs	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$nonrefs	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object;

typedef const struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vmethods	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtable	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtype	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$method$caseNewExpr$a19e03ca0d8a8f14(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$method$defaultCase$6711cf3c099fadd1(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$method_info$caseNewExpr$a19e03ca0d8a8f14;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$method_info$defaultCase$6711cf3c099fadd1;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vmethods {
	void	(*caseNewExpr$a19e03ca0d8a8f14)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object *, struct _jc_object *);
	void	(*defaultCase$6711cf3c099fadd1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vmethods	org_dellroad_jc_cgen_analysis_ReferenceDetector;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$refs {
    _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_refs	org_dellroad_jc_cgen_analysis_ReferenceDetector;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_nonrefs	org_dellroad_jc_cgen_analysis_ReferenceDetector;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object {
	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtype _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_ReferenceDetector, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_ReferenceDetector_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/analysis/ReferenceDetector.h <==
// public class org.dellroad.jc.cgen.analysis.ReferenceDetector

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 596609dfe74eee9e org_dellroad_jc_cgen_analysis_ReferenceDetector
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_ReferenceDetector_H_
#define _JC_org_dellroad_jc_cgen_analysis_ReferenceDetector_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_NewExpr$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_refs	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$refs	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$nonrefs	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object;

typedef const struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vmethods	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtable	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtype	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$method$caseNewExpr$a19e03ca0d8a8f14(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$method$defaultCase$6711cf3c099fadd1(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$method_info$caseNewExpr$a19e03ca0d8a8f14;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$method_info$defaultCase$6711cf3c099fadd1;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vmethods {
	void	(*caseNewExpr$a19e03ca0d8a8f14)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*defaultCase$6711cf3c099fadd1)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vmethods	org_dellroad_jc_cgen_analysis_ReferenceDetector;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$refs {
    _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_refs	org_dellroad_jc_cgen_analysis_ReferenceDetector;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$sub_nonrefs	org_dellroad_jc_cgen_analysis_ReferenceDetector;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$object {
	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$vtype _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_ReferenceDetector, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_ReferenceDetector$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_ReferenceDetector_H_ */
